@@ -3,8 +3,6 @@ require 'spec_helper'
 # parser OK.
 describe 'inherit_test1' do
   it {
-    should contain_inherit_ini_setting('valid_type').with({
-      'value' => 'true',
-    })
+    is_expected.to contain_inherit_ini_setting('valid_type').with('value' => 'true')
   }
 end
